@@ -7,8 +7,6 @@ from collections import defaultdict
 from pdb import set_trace
 from copy import copy
 
-from toolz import curry, identity
-
 from step import piped as step_into
 from stop_as_final_func import piped as stop_as_final_func
 
@@ -21,6 +19,10 @@ NOT_PRESENT = '__not__present__'
 MAX_OPERAND_STR_LEN = 70
 
 
+def identity(x):
+  return x
+
+
 def get_name(f):
   try:
     try:
